======
oli_ai
======


.. image:: https://img.shields.io/pypi/v/oli_ai.svg
        :target: https://pypi.python.org/pypi/oli_ai

.. image:: https://img.shields.io/travis/frhack/oli_ai.svg
        :target: https://travis-ci.com/frhack/oli_ai

.. image:: https://readthedocs.org/projects/oli-ai/badge/?version=latest
        :target: https://oli-ai.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Support library for Oli AI course


* Free software: MIT license
* Documentation: https://oli-ai.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
